 Function to output the characteristics of Gbemisola_Math_General

        Args: 
            length(int), 
            breath(int), 
            base(int), 
            height(int), 
            square_number(int), 
            random_range(int), 
            square_root(int), 
            square(int), 
            mode(array), 
            mean(array)

        Attributes:
            length: length of a rectangle, 
            breath: breath of a rectangle, 
            base: base of a triangle, 
            heigh: height of a rectangle, 
            square_number: squart number, 
            random_range: randome Range Number, 
            square_root: square root number, 
            square: square number of a square, 
            mode: array of numbers to get the mode, 
            mean: array of numbers to get the mean